@@ -1,19 +1,6 @@
-# Copyright (c) 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2014 Google, Inc.
-# Copyright (c) 2014 Cole Robinson <crobinso@redhat.com>
-# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
-# Copyright (c) 2015 David Shea <dshea@redhat.com>
-# Copyright (c) 2016 Jakub Wilk <jwilk@jwilk.net>
-# Copyright (c) 2016 Giuseppe Scrivano <gscrivan@redhat.com>
-# Copyright (c) 2018 Christoph Reiter <reiter.christoph@gmail.com>
-# Copyright (c) 2019 Philipp Hörist <philipp@hoerist.com>
-# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for the Python 2 GObject introspection bindings.
 
@@ -115,7 +102,7 @@ def _gi_build_stub(parent):
     ret = ""
 
     if constants:
-        ret += "# %s constants\n\n" % parent.__name__
+        ret += f"# {parent.__name__} constants\n\n"
     for name in sorted(constants):
         if name[0].isdigit():
             # GDK has some busted constant names like
@@ -132,23 +119,23 @@ def _gi_build_stub(parent):
     if ret:
         ret += "\n\n"
     if functions:
-        ret += "# %s functions\n\n" % parent.__name__
+        ret += f"# {parent.__name__} functions\n\n"
     for name in sorted(functions):
-        ret += "def %s(*args, **kwargs):\n" % name
+        ret += f"def {name}(*args, **kwargs):\n"
         ret += "    pass\n"
 
     if ret:
         ret += "\n\n"
     if methods:
-        ret += "# %s methods\n\n" % parent.__name__
+        ret += f"# {parent.__name__} methods\n\n"
     for name in sorted(methods):
-        ret += "def %s(self, *args, **kwargs):\n" % name
+        ret += f"def {name}(self, *args, **kwargs):\n"
         ret += "    pass\n"
 
     if ret:
         ret += "\n\n"
     if classes:
-        ret += "# %s classes\n\n" % parent.__name__
+        ret += f"# {parent.__name__} classes\n\n"
     for name, obj in sorted(classes.items()):
         base = "object"
         if issubclass(obj, Exception):
