@@ -1,18 +1,11 @@
-# Copyright (c) 2015-2016, 2018 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016 Ceridwen <ceridwenv@gmail.com>
-# Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
-
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-
+# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
 
 import collections
 from functools import lru_cache
 
-from astroid import context as contextmod
+from astroid.context import _invalidate_cache
 
 
 class TransformVisitor:
@@ -46,7 +39,7 @@ class TransformVisitor:
                 # if the transformation function returns something, it's
                 # expected to be a replacement for the node
                 if ret is not None:
-                    contextmod._invalidate_cache()
+                    _invalidate_cache()
                     node = ret
                 if ret.__class__ != cls:
                     # Can no longer apply the rest of the transforms.
@@ -92,5 +85,4 @@ class TransformVisitor:
         Only the nodes which have transforms registered will actually
         be replaced or changed.
         """
-        module.body = [self._visit(child) for child in module.body]
-        return self._transform(module)
+        return self._visit(module)
